CircleDataItem class

Pie chart Model class.

Constructors

CircleDataItem({required bool circleForwardFlg, required CircleShader circleShader, required double complementCircle, required double circleSizeValue, required double circleStrokeWidth, required double circleShadowValue, required int circleDuration, required Color circleColor, required Color circleShadowColor, required Color circleRoundColor, required CircleProgressController circleController, required List<List<Color>> circleColorList, double? circleCounterValue, double? circlePointerValue, double? circleLabelValue, double? circleLabelSpeedValue, double? circleSpeedCounterValue, double? circleCombinedTextSize, Size? graphTextSize, double? circleTapValue, double? circleDefaultTapValue, int? circleTapIndex, List<Size>? circleTextSizeList, List<Size>? circleTextMarginList, List<Color>? circleCombinedColor, List<Color>? circleCombinedColorList, List<double>? startValue, List<double>? endValue, List<String>? circleListText})

Properties

circleColor ↔ Color
getter/setter pair
circleColorList ↔ List<List<Color>>
getter/setter pair
circleCombinedColor ↔ List<Color>?
getter/setter pair
circleCombinedColorList ↔ List<Color>?
getter/setter pair
circleCombinedTextSize ↔ double?
getter/setter pair
circleController ↔ CircleProgressController
getter/setter pair
circleCounterValue ↔ double?
getter/setter pair
circleDefaultTapValue ↔ double?
getter/setter pair
circleDuration ↔ int
getter/setter pair
circleForwardFlg ↔ bool
getter/setter pair
circleLabelSpeedValue ↔ double?
getter/setter pair
circleLabelValue ↔ double?
getter/setter pair
circlePointerValue ↔ double?
getter/setter pair
circleRoundColor ↔ Color
getter/setter pair
circleShader ↔ CircleShader
getter/setter pair
circleShadowColor ↔ Color
getter/setter pair
circleShadowValue ↔ double
getter/setter pair
circleSizeValue ↔ double
getter/setter pair
circleSpeedCounterValue ↔ double?
getter/setter pair
circleStrokeWidth ↔ double
getter/setter pair
circleTapIndex ↔ int?
getter/setter pair
circleTapValue ↔ double?
getter/setter pair
circleTextList ↔ List<String>?
getter/setter pair
circleTextMarginList ↔ List<Size>?
getter/setter pair
circleTextSizeList ↔ List<Size>?
getter/setter pair
complementCircle ↔ double
getter/setter pair
endValue ↔ List<double>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startValue ↔ List<double>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited