MultipleInfoDialog class

Build an alert UI for Dialog.

Inheritance

Constructors

MultipleInfoDialog({Key? key, Widget? content, Widget? titleWidget, double? elevation, double? actionsOverflowButtonSpacing, String? semanticLabel, EdgeInsetsGeometry? contentPadding = const EdgeInsets.fromLTRB(24.0, 20.0, 24.0, 24.0), TextStyle? titleTextStyle, TextStyle? contentTextStyle, List<Widget>? actions, EdgeInsetsGeometry actionsPadding = EdgeInsets.zero, EdgeInsetsGeometry? titlePadding, EdgeInsetsGeometry? buttonPadding, MainAxisAlignment? actionsAlignment, VerticalDirection? actionsOverflowDirection, Color? backgroundColor, Clip clipBehavior = Clip.none, ShapeBorder? shape, AlignmentGeometry? alignment, Rect? rect, bool scrollable = false})
const

Properties

actions → List<Widget>?
final
actionsAlignment → MainAxisAlignment?
final
actionsOverflowButtonSpacing → double?
final
actionsOverflowDirection → VerticalDirection?
final
actionsPadding → EdgeInsetsGeometry
final
alignment → AlignmentGeometry?
final
backgroundColor → Color?
final
buttonPadding → EdgeInsetsGeometry?
final
clipBehavior → Clip
final
content → Widget?
final
contentPadding → EdgeInsetsGeometry?
final
contentTextStyle → TextStyle?
final
elevation → double?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
rect → Rect?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollable → bool
final
semanticLabel → String?
final
shape → ShapeBorder?
final
titlePadding → EdgeInsetsGeometry?
final
titleTextStyle → TextStyle?
final
titleWidget → Widget?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited