OverlappingIndicator class abstract

Abstract model class

Inheritance
Implementers

Constructors

OverlappingIndicator({Key? key, GlobalKey<State<StatefulWidget>>? globalKey, String? semanticsLabel, String? semanticsValue, Size? contextSize, int? graphCount, CircleData? circleData, double? animationValue, RadData? radData, CustomPaint? setPaint, double? boxSize, double? navigationHeight, required TextSpan? textSpan, required BuildContext con, required List<String> dialogData, required StreamController<List> streamController})
const

Properties

animationValue → double?
final
boxSize → double?
final
circleData → CircleData?
final
con → BuildContext
final
contextSize → Size?
final
dialogData → List<String>
final
globalKey → GlobalKey<State<StatefulWidget>>?
final
graphCount → int?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
final
radData → RadData?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticsLabel → String?
final
semanticsValue → String?
final
setPaint → CustomPaint?
final
streamController → StreamController<List>
final
textSpan → TextSpan?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited