OverlappingPainter class

The OverlappingPainter class is a class that sets overlapping graphs.

Inheritance

Constructors

OverlappingPainter({required double? widgetSize, required double? value, required int? graphCount, required Size contextSize, required Offset offsetValue, required CircleData? circleData, required RadData? radData, required Color backgroundColor, required TextSpan? textSpan, required List<String>? dialogData, required StreamController<List> controller})

Properties

backgroundColor → Color
final
circleData → CircleData?
final
contextSize → Size
final
controller → StreamController<List>
final
count ↔ int
getter/setter pair
dialogData → List<String>?
final
graphCount → int?
final
hashCode → int
The hash code for this object.
no setterinherited
offsetValue → Offset
final
radData → RadData?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticsBuilder → SemanticsBuilderCallback?
Returns a function that builds semantic information for the picture drawn by this painter.
no setterinherited
textSpan → TextSpan?
final
value → double?
final
widgetSize → double?
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be notified when it is time to repaint.
inherited
hitTest(Offset position) → bool
Class to publish when tapped.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size) → void
Method to set roundness
override
paintBar(Size size, Canvas canvas, TextSpan? span) → void
Character arrangement according to height and width.
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies when it is time to repaint.
inherited
shouldRebuildSemantics(covariant CustomPainter oldDelegate) → bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
inherited
shouldRepaint(covariant OverlappingPainter oldDelegate) → bool
Update the value as the color changes
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited