OverlappingProgressIndicator class

OverlappingProgressIndicator is a class that calculates UI other than graphs.

Inheritance

Constructors

OverlappingProgressIndicator({Key? key, RadData radData = RadData.horizontal, Size? contextSize, int? graphCount, double? minHeight, GlobalKey<State<StatefulWidget>>? globalKey, String? textValue, double? animationValue, TextSpan? textSpan, CustomPaint? setPaint, required double boxSize, required double foldHeight, required BuildContext con, required List<String> dialogData, required StreamController<List> streamController})
const

Properties

animationValue → double?
finalinherited
boxSize → double?
finalinherited
circleData → CircleData?
finalinherited
con → BuildContext
finalinherited
contextSize → Size?
finalinherited
dialogData → List<String>
finalinherited
globalKey → GlobalKey<State<StatefulWidget>>?
finalinherited
graphCount → int?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
minHeight → double?
final
finalinherited
radData → RadData?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticsLabel → String?
finalinherited
semanticsValue → String?
finalinherited
setPaint → CustomPaint?
finalinherited
streamController → StreamController<List>
finalinherited
textSpan → TextSpan?
finalinherited

Methods

buildSemanticsWrapper({required BuildContext context, required Widget child}) → Widget
controllerStream() → dynamic
bind the tap location.
createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<OverlappingProgressIndicator>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setPainter(Offset offset, String textValue, double value, double scale, Color painterColor, {CircleData circleData = CircleData.none, Color backColor = Colors.grey, Color? textColor = Colors.black}) → OverlappingPainter?
Calculations for painting TextSpan.
showMyDialog(BuildContext context, Offset dataPosition, {String? dialogText}) → Future<void>
Method to calculate alert.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited